"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = require("path");
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
function rehypeDocs({ filePath, tag, processor }) {
    function visitInlineCode(node) {
        const value = node.value;
        if (value.startsWith('markdown:')) {
            const file = value.substr(9);
            const path = path_1.dirname(filePath) + '/' + file;
            if (!fs_1.default.existsSync(path)) {
                throw Error(`Invalid fragment specified; no such file "${path}"`);
            }
            const code = fs_1.default.readFileSync(path, 'utf8');
            const markdown = processor();
            try {
                node.value = `<div class=\"markdown-fragment\">${markdown.processSync(code)}</div>`;
                node.type = 'html';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
    }
    function visitLink(node) {
        // console.log(node);
        if (node.children.length > 0 && node.children[0].value === '!embed') {
            const file = node.url;
            const path = path_1.dirname(filePath) + '/' + file;
            if (!fs_1.default.existsSync(path)) {
                throw Error(`Invalid fragment specified; no such file "${path}"`);
            }
            const code = fs_1.default.readFileSync(path, 'utf8');
            const markdown = processor();
            try {
                node.value = `<div class=\"markdown-fragment\">${markdown.processSync(code)}</div>`;
                node.type = 'html';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
    }
    return function transformer(tree) {
        unist_util_visit_1.default(tree, 'inlineCode', visitInlineCode);
        unist_util_visit_1.default(tree, (node) => node.type === 'link', visitLink);
        return tree;
    };
}
exports.default = rehypeDocs;
//# sourceMappingURL=rehypeMarkdown.js.map